<?php

namespace Drupal\atoms;

use Drupal\Component\Plugin\DerivativeInspectionInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Config\Config;
use Drupal\Core\Form\FormStateInterface;

interface AtomsPluginInterface extends PluginInspectionInterface, DerivativeInspectionInterface
{

  /**
   * Returns an array of names of content types for use in the administration
   * interface.
   *
   * @return array
   */
  public function getTypeNames();

  /**
   * Tells whether the plugin supports tokens or not.
   *
   * @return bool
   */
  public function hasTokenSupport();

  /**
   * @param $setting
   *
   * @return mixed|null
   */
  public function getRenderSettings($setting);

  /**
   * @param ViewableAtom $view
   * @param string $key
   *
   * @return mixed
   */
  public function value(ViewableAtom $view, $key = '');

  /**
   * @param ViewableAtom $view
   *
   * @return array
   */
  public function values(ViewableAtom $view);

  /**
   * @param ViewableAtom $view
   *
   * @return array
   *   A render array to render the atom type.
   */
  public function render(ViewableAtom $view);

  /**
   * @param Atom $atom
   *
   * @return array
   *   A render array to render a summery of the atom type.
   */
  public function summary(Atom $atom);

  /**
   * @param \Drupal\atoms\Atom $atom
   *
   * @return array
   */
  public function formBuilder(Atom $atom);

  /**
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return bool
   */
  public function validate(&$form, FormStateInterface $form_state);

  /**
   * @param \Drupal\atoms\Atom $atom
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function submit(Atom $atom, FormStateInterface $form_state);

  /**
   * @param \Drupal\Core\Config\Config $config
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return array
   */
  public function settingsForm(Config $config, FormStateInterface $form_state);

  /**
   * @param \Drupal\Core\Config\Config $config
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *
   * @return bool
   */
  public function settingsValidate(Config $config, FormStateInterface $form_state);

  /**
   * @param \Drupal\Core\Config\Config $config
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public function settingsSubmit(Config $config, FormStateInterface $form_state);

}
