<?php

namespace Drupal\atoms;

use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Security\TrustedCallbackInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class AtomsViewBuilder implements TrustedCallbackInterface
{

  private $manager;

  private $storage;

  private $requestStack;

  public function __construct(AtomsManager $manager, AtomsStorage $storage, RequestStack $requestStack)
  {
    $this->manager = $manager;
    $this->storage = $storage;
    $this->requestStack = $requestStack;
  }

  /**
   * @inheritDoc
   */
  public static function trustedCallbacks()
  {
    return ['buildAtom'];
  }

  /**
   * @param $machine_name
   * @param null $langcode
   *
   * @return array
   */
  public function getLazyBuilder($machine_name, $langcode = NULL)
  {
    $langcode = (empty($langcode)) ? \Drupal::languageManager()
      ->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)
      ->getId() : $langcode;
    return [
      '#lazy_builder' => [
        'atoms:buildAtom',
        [
          'machine_name' => $machine_name,
          'langcode' => $langcode,
        ],
      ],
      '#create_placeholder' => TRUE,
    ];
  }

  public function buildAtom($machine_name, $langcode)
  {
    return $this->get($machine_name, $langcode)->toRenderable();
  }

  /**
   * @param string $machine_name
   * @param string|null $langcode
   *
   * @return ViewableAtom
   */
  public function get($machine_name, $langcode = NULL)
  {
    $views = &drupal_static(__FUNCTION__, []);

    $langcode = (empty($langcode)) ? \Drupal::languageManager()
      ->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)
      ->getId() : $langcode;

    $key = $machine_name . ':' . $langcode;
    if (empty($views[$key])) {
      $views[$key] = new ViewableAtom($machine_name, $langcode);

      // If no atom uis yet defined, return the machine name.
      $this->addViewStatistics($machine_name, $langcode);
    }
    return $views[$key];
  }

  public function addViewStatistics($machine_name, $langcode = NULL)
  {
    // Add location of where Atom is called for statistics.
    $requestUri = $this->requestStack->getCurrentRequest()->getRequestUri();

  }

}
