<?php
/**
 * Created by PhpStorm.
 * User: pve
 * Date: 27/03/2018
 * Time: 21.33
 */

namespace Drupal\atoms\Form;


use Drupal\atoms\Atom;
use Drupal\Component\Utility\Unicode;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

class AtomsOverviewListForm extends AtomsOverviewBaseForm
{


  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId()
  {
    return 'atoms_overview_list';
  }

  /**
   * Form constructor.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $form = parent::buildForm($form, $form_state);

    $form['#attached']['library'][] = 'core/drupal.tableresponsive';

    $form['list'] = [
      '#type' => 'table',
      '#header' => [$this->t('Title'), $this->t('Category'), $this->t('Fields'), $this->t('Operations')],
      '#empty' => $this->t('There are no texts yet.'),
      '#tableselect' => FALSE,
      '#attributes' => ['class' => ["responsive-enabled"]],
    ];
    foreach ($this->atoms as $category => $groups) {
      foreach ($groups as $group => $subgroups) {
        foreach ($subgroups as $subgroup => $atoms) {
          /** @var Atom $atom */
          foreach ($atoms as $atom) {
            if (!isset($form['list'][$group])) {
              $form['list'][$group] = [];
              $form['list'][$group]['title'] = [
                '#type' => 'link',
                '#title' => $group,
                '#url' => Url::fromRoute('atoms.edit', ['group_id' => $atom->getGroupID()]),
              ];
              $form['list'][$group]['category'] = [
                '#plain_text' => $category,
              ];
              $form['list'][$group]['category'] = [
                '#plain_text' => $category,
              ];
              $form['list'][$group]['fields'] = ['#plain_text' => ''];
              $fields = '';
            }

            if (!empty($fields)) {
              $fields .= ', ';
            }
            $fields .= $this->t($atom->getTitle());

            /*$form['list'][$group]['fields'][] = [
              '#type' => 'plan',
              '#title' => $this->t($globalContent->getTitle()),
              '#description' => Unicode::truncate($render, 100, FALSE, TRUE),
              '#description_display' => 'after',
            ];*/

            if (!isset($form['list'][$group]['operations'])) {
              $links = $this->getOperations($atom);
              $form['list'][$group]['operations'] = [
                '#type' => 'operations',
                '#links' => $links,
              ];
            }
          }
          $form['list'][$group]['fields']['#plain_text'] = Unicode::truncate($fields, 160, FALSE, TRUE);
        }
      }
    }

    $form['pager'] = ['#type' => 'pager'];

    return $form;
  }

  /**
   * @return string
   */
  protected function formRoute()
  {
    return 'atoms.overview';
  }

  /**
   * @return int
   */
  protected function searchLimit()
  {
    return 20;
  }

}
