<?php

namespace Drupal\atoms\Plugin\Atoms;

use Drupal\atoms\Atom;
use Drupal\atoms\AtomsPluginBase;
use Drupal\atoms\ViewableAtom;
use Drupal\Core\Form\FormStateInterface;

/**
 * @Atoms(
 *  id = "checkbox",
 *  title = "Checkbox",
 *  description = "Checkbox fields",
 *  types = {
 *    "checkbox"
 *  }
 * )
 */
class Checkbox extends AtomsPluginBase
{

  /**
   * @inheritDoc
   */
  public function getTypeNames()
  {
    return [
      'checkbox' => 'Checkbox'
    ];
  }

  /**
   * @inheritDoc
   */
  public function hasTokenSupport()
  {
    return FALSE;
  }

  /**
   * @inheritDoc
   */
  public function formBuilder(Atom $atom)
  {
    $value = (bool)$atom->getData();

    return [
      '#type' => 'checkbox',
      '#title' => $this->t($atom->getTitle()),
      '#description' => $this->t($atom->getDescription()),
      '#default_value' => $value,
    ];
  }

  /**
   * @inheritDoc
   */
  public function submit(Atom $atom, FormStateInterface $form_state)
  {
    $atom->setData((bool)$form_state->getValue($this->getFormStateKey($atom)));
  }

  /**
   * @inheritDoc
   */
  public function renderBuild(ViewableAtom $view, array &$build)
  {
    $data = $view->getData();

    $boolean = $this->prepareText($view, $data);
    $value = $this->t('Yes');
    if (!is_bool($boolean) || !$boolean) {
      $value = $this->t('No');
    }

    $build = ['#markup' => $value];
  }

  /**
   * @inheritDoc
   */
  public function summary(Atom $atom)
  {
    $boolean = $atom->getData();

    $value = $this->t('Yes');
    if (!is_bool($boolean) || !$boolean) {
      $value = $this->t('No');
    }

    return ['#markup' => $value];
  }

  /**
   * @inheritDoc
   */
  public function value(ViewableAtom $view, $key = '')
  {
    $boolean = $view->getData();
    return $boolean;
  }
}
