<?php

namespace Drupal\atoms\Plugin\Atoms;

use Drupal\atoms\Atom;
use Drupal\atoms\AtomsPluginBase;
use Drupal\atoms\ViewableAtom;
use Drupal\Core\Config\Config;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Datetime\Entity\DateFormat;
use Drupal\Core\Form\FormStateInterface;

/**
 * @Atoms(
 *  id = "datetime",
 *  title = "Date Time",
 *  description = "Date and time",
 *  types = {
 *    "date",
 *    "datetime"
 *  }
 * )
 */
class DateTime extends AtomsPluginBase
{

  /**
   * @inheritDoc
   */
  public function getTypeNames()
  {
    return [
      'date' => 'Date',
      'datetime' => 'Date and time',
    ];
  }

  /**
   * @inheritDoc
   */
  public function hasTokenSupport()
  {
    return FALSE;
  }

  /**
   * @inheritDoc
   */
  public function formBuilder(Atom $atom)
  {

    $form = [
      '#type' => 'datetime',
      '#title' => $this->t($atom->getTitle()),
      '#description' => $this->t($atom->getDescription()),
      '#default_value' => $atom->getData(),
    ];

    return $form;
  }

  /**
   * @inheritDoc
   */
  function renderBuild(ViewableAtom $view, array &$build)
  {
    /** @var \Drupal\Core\Datetime\DateFormatter $dateFormatter */
    $dateFormatter = \Drupal::service('date.formatter');
    /** @var DrupalDateTime $datetime */
    $datetime = $view->getData();
    if (!empty($datetime)) {
      $format = $view->getOptions()['format'] ?? ($this->getConfig()
        ->get($this->getPluginId() . '_format') ?? 'medium');
      $build = ['#markup' => $dateFormatter->format($datetime->getTimestamp(), $format)];
    }
  }

  /**
   * @inheritDoc
   */
  public function summary(Atom $atom)
  {
    /** @var \Drupal\Core\Datetime\DateFormatter $dateFormatter */
    $dateFormatter = \Drupal::service('date.formatter');
    /** @var DrupalDateTime $datetime */
    $datetime = $atom->getData();
    $format = $atom->getOptions()['format'] ?? ($this->getConfig()
      ->get($this->getPluginId() . '_format') ?? 'medium');
    if (empty($datetime)) {
      return [];
    } else {
      return ['#markup' => $dateFormatter->format($datetime->getTimestamp(), $format)];
    }
  }

  /**
   * @inheritDoc
   */
  public function value(ViewableAtom $view, $key = '')
  {
    return $view->getData();
  }

  /**
   * @inheritDoc
   */
  public function settingsForm(Config $config, FormStateInterface $form_state)
  {
    $date_types = DateFormat::loadMultiple();
    $date_formatter = \Drupal::service('date.formatter');
    $date_formats = [];
    /** @var DateFormat $format */
    foreach ($date_types as $machine_name => $format) {
      $date_formats[$machine_name] = t('@name format', ['@name' => $format->label()]) . ': ' . $date_formatter->format(\Drupal::time()
          ->getRequestTime(), $machine_name);
    }

    $form[$this->getPluginId() . '_format'] = [
      '#type' => 'select',
      '#title' => $this->t('Default date format'),
      '#options' => $date_formats,
      '#default_value' => $config->get($this->getPluginId() . '_format') ?: 'medium',
    ];

    return $form;
  }

  /**
   * @inheritDoc
   */
  public function settingsValidate(Config $config, FormStateInterface $form_state)
  {
    return TRUE;
  }

  /**
   * @inheritDoc
   */
  public function settingsSubmit(Config $config, FormStateInterface $form_state)
  {
    $config->set($this->getPluginId() . '_format', $form_state->getValue($this->getPluginId() . '_format'));
  }

}
