<?php

namespace Drupal\atoms\Plugin\Atoms;

use Drupal\atoms\Atom;
use Drupal\atoms\AtomsPluginBase;
use Drupal\atoms\ViewableAtom;
use Drupal\Console\Bootstrap\Drupal;
use Drupal\token\Token;

/**
 * @Atoms(
 *  id = "number",
 *  title = "Number",
 *  description = "Number fields",
 *  types = {
 *    "number"
 *  }
 * )
 */
class Number extends AtomsPluginBase
{

  /**
   * @inheritDoc
   */
  public function getTypeNames()
  {
    return [
      'number' => 'Number'
    ];
  }

  /**
   * @inheritDoc
   */
  public function hasTokenSupport()
  {
    return FALSE;
  }

  /**
   * @inheritDoc
   */
  public function formBuilder(Atom $atom)
  {
    $value = $atom->getData();

    $form = [
      '#type' => $atom->getType(),
      '#title' => $this->t($atom->getTitle()),
      '#description' => $this->t($atom->getDescription()),
      '#default_value' => is_array($value) ? $value['value'] : intval($value),
    ];

    return $form;
  }

  /**
   * @inheritDoc
   */
  public function renderBuild(ViewableAtom $view, array &$build)
  {
    $number = $this->prepareText($view, $view->getData());
    $build = ['#plain_text' => $number];
  }

  /**
   * @inheritDoc
   */
  public function summary(Atom $atom)
  {
    return ['#plain_text' => $atom->getData()];
  }

  /**
   * @inheritDoc
   */
  public function value(ViewableAtom $view, $key = '')
  {
    return intval($view->getData());
  }
}
