<?php

namespace Drupal\atoms\Plugin\Atoms;

use Drupal\atoms\Atom;
use Drupal\atoms\AtomsPluginBase;
use Drupal\atoms\ViewableAtom;
use Drupal\Console\Bootstrap\Drupal;
use Drupal\token\Token;

/**
 * @Atoms(
 *  id = "text",
 *  title = "Text",
 *  description = "Text fields",
 *  types = {
 *    "textfield",
 *    "textarea",
 *    "email"
 *  }
 * )
 */
class Text extends AtomsPluginBase
{

  /**
   * @inheritDoc
   */
  public function getTypeNames()
  {
    return [
      'textfield' => 'Text (plain)',
      'textarea' => 'Text (plain, long)',
      'email' => 'E-mail',
    ];
  }

  /**
   * @inheritDoc
   */
  public function hasTokenSupport()
  {
    return TRUE;
  }

  /**
   * @inheritDoc
   */
  public function formBuilder(Atom $atom)
  {
    $value = $atom->getData();

    $form = [
      '#type' => $atom->getType(),
      '#title' => $this->t($atom->getTitle()),
      '#description' => $this->t($atom->getDescription()),
      '#default_value' => is_array($value) ? $value['value'] : $value,
      '#maxlength' => 255,
    ];

    if ($this->isTokenSupportEnabled()) {
      $form['#element_validate'] = ['token_element_validate'];
      $form['#token_types'] = $atom->getTokenTypes();
    }
    return $form;
  }

  /**
   * @inheritDoc
   */
  public function renderBuild(ViewableAtom $view, array &$build)
  {
    $text = $this->prepareText($view, $view->getData());
    $build = ['#plain_text' => $text];
  }

  /**
   * @inheritDoc
   */
  public function summary(Atom $atom)
  {
    return ['#plain_text' => $atom->getData()];
  }

}
