<?php

namespace Drupal\atoms\Plugin\Transform\Type;

use Drupal\atoms\Atom as AtomItem;
use Drupal\atoms\Transform\AtomTransform;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\transform_api\EventSubscriber\TransformationCache;
use Drupal\transform_api\Transform\TransformInterface;
use Drupal\transform_api\TransformationTypeBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @TransformationType(
 *  id = "atom",
 *  title = "Atom transform"
 * )
 */
class Atom extends TransformationTypeBase
{

  /**
   * @var \Drupal\transform_api\EventSubscriber\TransformationCache
   */
  protected TransformationCache $transformationCache;

  function __construct(array $configuration, $plugin_id, $plugin_definition, TransformationCache $transformationCache)
  {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->transformationCache = $transformationCache;
  }

  /**
   * @inheritDoc
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition)
  {
    return new static($configuration, $plugin_id, $plugin_definition,
      $container->get('transform_api.transformation_cache')
    );
  }

  /**
   * @inheritDoc
   */
  public function transform(TransformInterface $transform)
  {
    /** @var \Drupal\atoms\Transform\AtomTransform $atom_transform */
    $atom_transform = $transform;
    if (is_array($transform->getValue('ids'))) {
      return $this->prepareMultipleTransforms($transform->getValue('ids'));
    } else {
      return $this->loadAndTransformAtom($transform->getValue('ids'));
    }
  }

  public function prepareMultipleTransforms(array $ids)
  {
    $transformation = [];
    foreach ($ids as $id) {
      $transform = new AtomTransform($id);
      $atom_transformation = $this->transformationCache->get($transform);
      if ($atom_transformation === FALSE) {
        $transformation[$id] = $transform;
      } else {
        $transformation[$id] = $atom_transformation;
      }
    }

    return $transformation;
  }

  public function loadAndTransformAtom($id)
  {
    $atom = AtomItem::load($id);
    if (!empty($atom)) {
      $cacheMetadata = CacheableMetadata::createFromObject($atom);
      $transform = [
        'type' => 'atom',
        'machine_name' => $atom->getMachineName(),
        'atom_type' => $atom->getType()
      ];
      $data = $atom->view()->getValues();
      if (is_array($data)) {
        $transform += $data;
      } else {
        $transform['value'] = $data;
      }
      $cacheMetadata->applyTo($transform);
      return $transform;
    } else {
      return [];
    }
  }

}
