<?php

namespace Drupal\atoms\Twig;

use Drupal\atoms\AtomsViewBuilder;
use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;
use Twig\TwigFunction;

class AtomsExtension extends AbstractExtension
{

  protected $viewBuilder;

  /**
   * AtomsExtension constructor.
   *
   * @param \Drupal\atoms\AtomsViewBuilder $viewBuilder
   */
  public function __construct(AtomsViewBuilder $viewBuilder)
  {
    $this->viewBuilder = $viewBuilder;
  }

  /**
   * {@inheritdoc}
   */
  public function getName()
  {
    return 'atoms';
  }

  /**
   * {@inheritdoc}
   */
  public function getFunctions()
  {
    return [
      new TwigFunction('atom', [$this, 'atom'], ['is_safe' => ['html']]),
      new TwigFunction('atom_str', [$this, 'atom_str'], ['is_safe' => ['html']]),
      new TwigFunction('atom_lazy', [$this, 'atom_lazy'], ['is_safe' => ['html']]),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFilters()
  {
    return [
      new TwigFilter('atom', [$this, 'atom']),
      new TwigFilter('atom_str', [$this, 'atom_str']),
      new TwigFilter('atom_lazy', [$this, 'atom_lazy']),
    ];
  }

  /**
   * Provides atoms function to Twig templates.
   *
   * @param string $machine_name
   *   The machine name for the atom instance.
   * @param null $langcode
   *
   * @return array
   */
  public function atom($machine_name, $langcode = NULL)
  {
    return $this->viewBuilder->get($machine_name, $langcode)->toRenderable();
  }

  /**
   * Provides atoms function to Twig templates.
   *
   * @param string $machine_name
   *   The machine name for the atom instance.
   * @param null $langcode
   *
   * @return array
   */
  public function atom_lazy($machine_name, $langcode = NULL)
  {
    return $this->viewBuilder->getLazyBuilder($machine_name, $langcode);
  }

  /**
   * Provides atoms function to Twig templates.
   *
   * @param string $machine_name
   *   The machine name for the atom instance.
   * @param null $langcode
   *
   * @return string
   */
  public function atom_str($machine_name, $langcode = NULL)
  {
    return $this->viewBuilder->get($machine_name, $langcode)->toString();
  }

}
